@@ -43,7 +43,6 @@
 #include "shuffle.h"
 #include "speeds.h"
 #include "patsolve/solverinterface.h"
-#include "version.h"
 #include "view.h"
 
 #include "KCardTheme"
@@ -793,7 +792,7 @@ MoveHint DealerScene::chooseHint()
         qreal randomExp = qMin<qreal>( -log( 1 - qreal( KRandom::random() ) / RAND_MAX ) / 4, 1 );
         int randomIndex =  randomExp * ( hintList.size() - 1 );
 
-	qSort(hintList.begin(), hintList.end(), prioSort);
+        std::sort(hintList.begin(), hintList.end(), prioSort);
         return hintList.at( randomIndex );
     }
 }
