@@ -40,6 +40,7 @@
 #include "speeds.h"
 #include "patsolve/golfsolver.h"
 #include "pileutils.h"
+#include "settings.h"
 
 #include <KLocalizedString>
 
@@ -88,7 +89,9 @@ void Golf::initialize()
     }
 
     setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Draw);
-    setSolver( new GolfSolver( this ) );
+    auto solver = new GolfSolver( this );
+    solver->default_max_positions = Settings::golfSolverIterationsLimit();
+    setSolver( solver );
 
     connect( this, &KCardScene::cardClicked, this, &DealerScene::tryAutomaticMove );
 }
@@ -173,13 +176,13 @@ void Golf::setGameState( const QString & state )
 QString Golf::solverFormat() const
 {
     QString output;
-    output += QStringLiteral("Foundations: ") + (waste->isEmpty() ? QStringLiteral("-") : cardToRankSuitString(waste->topCard())) + '\n';
+    output += QLatin1String("Foundations: ") + (waste->isEmpty() ? QLatin1String("-") : cardToRankSuitString(waste->topCard())) + '\n';
     output += QLatin1String("Talon:");
     for ( int i = talon->count()-1; i >= 0; --i )
     {
-        output += QStringLiteral(" ")+cardToRankSuitString(talon->at( i ));
+        output += QLatin1Char(' ')+cardToRankSuitString(talon->at( i ));
     }
-    output += QLatin1String("\n");
+    output += QLatin1Char('\n');
     for (int i = 0; i < 7 ; i++)
         cardsListToLine(output, stack[i]->cards());
     return output;
