@@ -49,8 +49,8 @@ public:
     QDateTime lastModified() const;
     QSet<QString> supportedFeatures() const;
 
-    bool operator==( KCardTheme theme ) const;
-    bool operator!=( KCardTheme theme ) const;
+    bool operator==( const KCardTheme &theme ) const;
+    bool operator!=( const KCardTheme &theme ) const;
 
 private:
     QSharedDataPointer<const KCardThemePrivate> d;
