@@ -24,7 +24,7 @@
 #include "abstract_fc_solve_solver.h"
 
 const int CHUNKSIZE = 100;
-const long int MAX_ITERS_LIMIT = 200000;
+const long int INITIAL_MAX_ITERS_LIMIT = 200000;
 
 #define PRINT 0
 
@@ -51,15 +51,25 @@ const auto SOFT_SUSPEND = FCS_STATE_SUSPEND_PROCESS;
 SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
 {
     int current_iters_count;
-    max_positions = (_max_positions < 0) ? MAX_ITERS_LIMIT : _max_positions;
+    max_positions = (_max_positions < 0) ? default_max_positions : _max_positions;
 
     init();
 
+    // call free once the function ends. ### Replace this mess with QScopeGuard once we can use Qt 5.12
+    auto cleanup = [this](){this->free();};
+    using CleanupFunction = decltype (cleanup);
+    struct CleanupHandler {
+        CleanupHandler(CleanupFunction cleanup) : m_cleanup(std::move(cleanup)) {}
+        ~CleanupHandler() { m_cleanup();}
+
+        CleanupFunction m_cleanup;
+    } cleaner(cleanup);
+
     int no_use = 0;
     int num_moves = 0;
     const auto get_possible_moves__ret = get_possible_moves(&no_use, &num_moves);
     Q_ASSERT( num_moves == get_possible_moves__ret );
-    Q_ASSERT( m_firstMoves.count() == 0 );
+    Q_ASSERT( m_firstMoves.isEmpty() );
     for (int j = 0; j < num_moves; ++j)
         m_firstMoves.append( Possible[j] );
     // Sometimes the solver is invoked with a small maximal iterations
@@ -110,7 +120,7 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
         current_iters_count = CHUNKSIZE;
         set_soft_limit(solver_instance, current_iters_count);
 #ifdef WITH_FCS_SOFT_SUSPEND
-        freecell_solver_user_limit_iterations(solver_instance, MAX_ITERS_LIMIT);
+        freecell_solver_user_limit_iterations(solver_instance, max_positions);
 #endif
     }
 
@@ -121,7 +131,7 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
                 (   (solver_ret == FCS_STATE_NOT_BEGAN_YET)
                  || (solver_ret == SOFT_SUSPEND))
                     &&
-                 (current_iters_count < MAX_ITERS_LIMIT)
+                 (current_iters_count < max_positions)
               )
         {
             current_iters_count += CHUNKSIZE;
@@ -149,7 +159,7 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
         }
     }
     const long reached_iters = freecell_solver_user_get_num_times_long(solver_instance);
-    Q_ASSERT(reached_iters <= MAX_ITERS_LIMIT);
+    Q_ASSERT(reached_iters <= default_max_positions);
 #if 0
     fprintf(stderr, "iters = %ld\n", reached_iters);
 #endif
@@ -219,6 +229,7 @@ int FcSolveSolver::getOuts()
 FcSolveSolver::FcSolveSolver()
     : Solver()
     , solver_instance(NULL)
+    , default_max_positions(INITIAL_MAX_ITERS_LIMIT)
     , solver_ret(FCS_STATE_NOT_BEGAN_YET)
     , board_as_string("")
 {
