@@ -22,11 +22,11 @@ class Grandf;
 #include "patsolve.h"
 
 
-class GrandfSolver : public Solver
+class GrandfSolver : public Solver<7*3+1>
 {
 public:
     explicit GrandfSolver(const Grandf *dealer);
-    int good_automove(int o, int r);
+
     int get_possible_moves(int *a, int *numout) Q_DECL_OVERRIDE;
     bool isWon() Q_DECL_OVERRIDE;
     void make_move(MOVE *m) Q_DECL_OVERRIDE;
